@@ -134,6 +134,9 @@ struct ble_ll_iso_big {
     uint32_t sync_delay;
     uint32_t event_start;
     uint8_t event_start_us;
+    uint32_t anchor_base_ticks;
+    uint8_t anchor_base_rem_us;
+    uint16_t anchor_offset;
     struct ble_ll_sched_item sch;
     struct ble_npl_event event_done;
 
@@ -168,6 +171,37 @@ static uint8_t bis_pool_free = BIS_POOL_SIZE;
 static struct ble_ll_iso_big *big_pending;
 static struct ble_ll_iso_big *big_active;
 
+static void
+big_sched_set(struct ble_ll_iso_big *big)
+{
+    uint32_t offset_us;
+
+    big->sch.start_time = big->anchor_base_ticks;
+    big->sch.remainder = big->anchor_base_rem_us;
+
+    offset_us = big->anchor_offset * big->iso_interval * 1250;
+
+    ble_ll_tmr_add(&big->sch.start_time, &big->sch.remainder, offset_us);
+
+    /* Reset anchor base before anchor offset wraps-around.
+     * This happens much earlier than possible overflow in calculations.
+     */
+    if (big->anchor_offset == UINT16_MAX) {
+        big->anchor_base_ticks = big->sch.start_time;
+        big->anchor_base_rem_us = big->sch.remainder;
+        big->anchor_offset = 0;
+    }
+
+    big->sch.end_time = big->sch.start_time +
+                        ble_ll_tmr_u2t_up(big->sync_delay) + 1;
+    big->sch.start_time -= g_ble_ll_sched_offset_ticks;
+
+    if (big->control_active) {
+        /* XXX calculate proper time */
+        big->sch.end_time += 10;
+    }
+}
+
 struct ble_ll_iso_bis *
 ble_ll_iso_big_find_bis_by_handle(uint16_t conn_handle)
 {
@@ -273,20 +307,38 @@ ble_ll_iso_big_biginfo_copy(struct ble_ll_iso_big *big, uint8_t *dptr,
                             uint32_t base_ticks, uint8_t base_rem_us)
 {
     uint8_t *dptr_start;
+    uint32_t event_start;
+    uint8_t event_start_us;
     uint64_t counter;
     uint32_t offset_us;
     uint32_t offset;
-    uint32_t d_ticks;
-    uint8_t d_rem_us;
 
     dptr_start = dptr;
     counter = big->bis_counter;
 
-    d_ticks = big->event_start - base_ticks;
-    d_rem_us = big->event_start_us;
-    ble_ll_tmr_sub(&d_ticks, &d_rem_us, base_rem_us);
+    event_start = big->event_start;
+    event_start_us = big->event_start_us;
+
+    /* Use next BIG event in case current one is before AUX_SYNC_IND. This can
+     * happen if AUX_SYNC_IND is scheduled right after BIG event and the BIG
+     * was not yet advanced to next event.
+     */
+    if (event_start <= base_ticks) {
+        ble_ll_tmr_add(&event_start, &event_start_us, big->iso_interval * 1250);
+        counter++;
+    }
+
+    /* Drop BIGInfo if BIG event is still before AUX_SYNC_IND. This should not
+     * happen but better not send invalid offset.
+     */
+    if (event_start <= base_ticks) {
+        return 0;
+    }
+
+    offset_us = ble_ll_tmr_t2u(event_start - base_ticks);
+    offset_us += event_start_us;
+    offset_us -= base_rem_us;
 
-    offset_us = ble_ll_tmr_t2u(d_ticks) + d_rem_us;
     if (offset_us <= 600) {
         counter += big->bn;
         offset_us += big->iso_interval * 1250;
@@ -536,18 +588,8 @@ ble_ll_iso_big_event_done(struct ble_ll_iso_big *big)
             }
         }
 
-        /* XXX precalculate some data here? */
-
-        ble_ll_tmr_add(&big->sch.start_time, &big->sch.remainder,
-                       big->iso_interval * 1250);
-        big->sch.end_time = big->sch.start_time +
-                            ble_ll_tmr_u2t_up(big->sync_delay) + 1;
-        big->sch.start_time -= g_ble_ll_sched_offset_ticks;
-
-        if (big->control_active) {
-            /* XXX fixme */
-            big->sch.end_time += 10;
-        }
+        big->anchor_offset++;
+        big_sched_set(big);
 
         /* XXX this should always succeed since we preempt anything for now */
         rc = ble_ll_sched_iso_big(&big->sch, 0, 0);
@@ -1083,40 +1125,40 @@ ble_ll_iso_big_create(uint8_t big_handle, uint8_t adv_handle, uint8_t num_bis,
      * not enough for some phys to run scheduler item.
      */
 
-    uint32_t start_time, end_time, big_time;
+    uint32_t padv_start_time, big_start_time;
     uint32_t sync_delay_ticks = ble_ll_tmr_u2t_up(big->sync_delay);
-    uint32_t iso_interval_ticks = ble_ll_tmr_u2t_up(big->iso_interval * 1250);
     int big_event_fixed;
 
-    rc = ble_ll_adv_sync_sched_get(big->advsm, &start_time, &end_time);
+    rc = ble_ll_adv_padv_event_start_get(big->advsm, &padv_start_time, NULL);
     if (rc) {
-        /* Set 1st BIG one interval after "now", this ensures it's always
-         * scheduled in the future.
-         */
-        big_time = ble_ll_tmr_get() + iso_interval_ticks;
+        /* 1st event will be moved by 1 interval before scheduling so this will
+         * be always in the future */
+        big_start_time = ble_ll_tmr_get();
         big_event_fixed = 0;
     } else {
         /* Set 1st BIG event directly before periodic advertising event, this
          * way it will not overlap it even if periodic advertising data changes.
          * Make sure it's in the future.
          */
-        big_time = start_time - g_ble_ll_sched_offset_ticks - sync_delay_ticks - 1;
-        while (big_time - g_ble_ll_sched_offset_ticks < ble_ll_tmr_get()) {
-            big_time += iso_interval_ticks;
-        }
+        big_start_time = padv_start_time - g_ble_ll_sched_offset_ticks -
+                         sync_delay_ticks - 1;
         big_event_fixed = 1;
     }
 
-    big->sch.start_time = big_time;
-    big->sch.remainder = 0;
-    big->sch.end_time = big->sch.start_time + sync_delay_ticks + 1;
-    big->sch.start_time -= g_ble_ll_sched_offset_ticks;
+    big->anchor_base_ticks = big_start_time;
+    big->anchor_base_rem_us = 0;
+    big->anchor_offset = 0;
 
-    rc = ble_ll_sched_iso_big(&big->sch, 1, big_event_fixed);
-    if (rc < 0) {
-        ble_ll_iso_big_free(big);
-        return -EFAULT;
-    }
+    do {
+        big->anchor_offset++;
+        big_sched_set(big);
+
+        if (LL_TMR_LEQ(big->sch.start_time, ble_ll_tmr_get())) {
+            rc = -1;
+        } else {
+            rc = ble_ll_sched_iso_big(&big->sch, 1, big_event_fixed);
+        }
+    } while (rc < 0);
 
     ble_ll_iso_big_update_event_start(big);
 
@@ -1270,9 +1312,12 @@ ble_ll_iso_big_hci_create(const uint8_t *cmdbuf, uint8_t len)
     bp.encrypted = cmd->encryption;
     memcpy(bp.broadcast_code, cmd->broadcast_code, 16);
 
-    bp.nse = 1;
+    /* FIXME for now we only care about retransmissions, so set both NSE and IRC
+     * to RTN
+     */
+    bp.nse = MIN(cmd->rtn + 1, 0x0f);;
     bp.bn = 1;
-    bp.irc = 1;
+    bp.irc = MIN(cmd->rtn + 1, 0x0f);
     bp.pto = 0;
     bp.iso_interval = bp.sdu_interval / 1250;
     bp.max_pdu = bp.max_sdu;
