@@ -7,7 +7,9 @@
  */
 
 #include "syscfg/syscfg.h"
-#define MESH_LOG_MODULE BLE_MESH_LOW_POWER_LOG
+
+#define BLE_NPL_LOG_MODULE BLE_MESH_LOW_POWER_LOG
+#include <nimble/nimble_npl_log.h>
 
 #if MYNEWT_VAL(BLE_MESH_LOW_POWER)
 
