@@ -141,7 +141,8 @@ void ble_gap_mtu_event(uint16_t conn_handle, uint16_t cid, uint16_t mtu);
 void ble_gap_identity_event(uint16_t conn_handle, const ble_addr_t *peer_id_addr);
 int ble_gap_repeat_pairing_event(const struct ble_gap_repeat_pairing *rp);
 void ble_gap_pairing_complete_event(uint16_t conn_handle, int status);
-void ble_gap_vs_hci_event(const void *buf, uint8_t len);
+void ble_gap_unhandled_hci_event(bool is_le_meta, bool is_vs, const void *buf,
+                                 uint8_t len);
 int ble_gap_master_in_progress(void);
 
 void ble_gap_preempt(void);
